@@ -5,7 +5,6 @@ setGeneric("collocationAnalysis", function(kco, ...)  standardGeneric("collocati
 #' @aliases collocationAnalysis
 #'
 #' @description
-#' `r lifecycle::badge("experimental")`
 #'
 #' Performs a collocation analysis for the given node (or query)
 #' in the given virtual corpus.
@@ -20,8 +19,9 @@ setGeneric("collocationAnalysis", function(kco, ...)  standardGeneric("collocati
 #' To increase speed at the cost of accuracy and possible false negatives,
 #' you can decrease searchHitsSampleLimit and/or topCollocatesLimit and/or set exactFrequencies to FALSE.
 #'
-#' Note that currently not the tokenization provided by the backend, i.e. the corpus itself, is used, but a tinkered one.
-#' This can also lead to false negatives and to frequencies that differ from corresponding ones acquired via the web
+#' Note that some outdated non-DeReKo back-ends might not yet support returning tokenized matches (warning issued).
+#' In this case, the client library will fall back to client-side tokenization which might be slightly less accurate.
+#' This might lead to false negatives and to frequencies that differ from corresponding ones acquired via the web
 #' user interface.
 #'
 #' @family collocation analysis functions
@@ -99,7 +99,7 @@ setMethod("collocationAnalysis", "KorAPConnection",
               stop(sprintf("Not empty withinSpan (='%s') requires exactFrequencies=TRUE", withinSpan), call. = FALSE)
             }
 
-            warnIfNoAccessToken(kco)
+            warnIfNotAuthorized(kco)
 
             if (lemmatizeNodeQuery) {
               node <- lemmatizeWordQuery(node)
